import cocotb
from cocotbext_hyperbus import HyperBusController

@cocotb.test()
async def sample_test(dut):
    hbc=HyperBusController(dut)

    # hbc.Init(dut)
    await hbc.Reset(dut)
    Rx = await hbc.ReadReg(0)
    print(Rx)
    Rx = await hbc.ReadReg(2)
    print(Rx)
    # await hbc.WriteReg(2048,0xcf8f)
    Rx = await hbc.ReadReg(2048)
    print(Rx)
    Rx = await hbc.ReadReg(2049)
    print(Rx)

    await hbc.WriteMem(16,0xDEADBEEF)
    await hbc.WriteMem(0x13,0x1A2B3C4D)
    Rx = await hbc.ReadMem(16)
    print(Rx)

    Rx = await hbc.ReadMem(0x13)
    print(Rx)
    # await hbc.wait_100ns(dut)
    



# setup.py
from setuptools import setup, find_packages

__version__="0.1.6"
setup(
    name='cocotbext_hyperbus',
    version=__version__,
    description='A cocotb extension for HyperBus controllers',
    keywords=['cocotb', 'HyperBus'],
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    author='Meet Sangani',
    author_email='meet.sangani@outlook.com',
    license = 'MIT',
    url='https://github.com/meeeeet/cocotbext_hyperbus',
    packages=find_packages(),
    install_requires=[
        'cocotb',
    ],
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Framework :: cocotb',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Programming Language :: Python :: 3',
        'Topic :: Scientific/Engineering :: Electronic Design Automation (EDA)',
    ],
    python_requires='>=3.8',
)

